---
title: Improve documentation
type: change
author: mavam
created: 2025-12-06T00:03:57.030272Z
---

Simplified installation and usage instructions. Added notes on AWS SSO authentication and Base Event compatibility.
